"""A pure Python package for the scientific data analysis and plotting

PAIDA is pure Python scientific analysis package
and implements AIDA (Abstract Interfaces for Data Analysis).
The main features are:

 - Pure Python! (so works on both Python and Jython)
 - Creating/Plotting the histogram, ntuple, profile and cloud
 - Fitting parameter optimization with constraints and its parabolic and asymmetric error evaluation
 - XML based storing

AIDA project has other implementations like Java (JAIDA), C++ etc. (Open Scientist and Anaphe).
For more information about AIDA itself, please refer to
http://aida.freehep.org/

PAIDA web site:
http://paida.sourceforge.net/
"""

from distutils.core import setup
import os

doclines = __doc__.split(os.linesep)

classifiers = """\
Development Status :: 5 - Production/Stable
Intended Audience :: Science/Research
License :: OSI Approved :: Python Software Foundation License
Operating System :: OS Independent
Programming Language :: Java
Programming Language :: Python
Topic :: Scientific/Engineering
"""

packages = ['paida',
	'paida.paida_core',
	'paida.paida_gui',
	'paida.paida_gui.batch',
	'paida.paida_gui.tkinter',
	'paida.paida_gui.swing',
	'paida.math',
	'paida.math.optimize',
	'paida.math.pylapack',
	'paida.math.pylapack.pyblas',
	'paida.math.array',
	'paida.tools']

setup (name = "paida",
       version = "3.2.1_2.8",
       author = "Koji Kishimoto",
       author_email = "korry@users.sourceforge.net",
       url = "http://paida.sourceforge.net/",
       license = "Python Software Foundation License",
       platforms = ["any"],
       description = doclines[0],
       long_description = os.linesep.join(doclines[2:]),
       classifiers = filter(None, classifiers.split(os.linesep)),
       packages = packages
       )
